summaryrefslogtreecommitdiffstats
path: root/lib/libc/posix1e
diff options
context:
space:
mode:
authorjedgar <jedgar@FreeBSD.org>2001-03-29 00:48:54 +0000
committerjedgar <jedgar@FreeBSD.org>2001-03-29 00:48:54 +0000
commit304044bfea35b974efcdb3558d8a11c65afb7583 (patch)
treeadb8d21c1946b66da4004ca14c4e4fd76bb5b906 /lib/libc/posix1e
parent4641978b34f7caf2a4acd64c5ec62dec673fa99d (diff)
downloadFreeBSD-src-304044bfea35b974efcdb3558d8a11c65afb7583.zip
FreeBSD-src-304044bfea35b974efcdb3558d8a11c65afb7583.tar.gz
Correct function name: acl_clear_perm -> acl_clear_perms
Diffstat (limited to 'lib/libc/posix1e')
-rw-r--r--lib/libc/posix1e/acl_perm.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/libc/posix1e/acl_perm.c b/lib/libc/posix1e/acl_perm.c
index e314810..12ab17a 100644
--- a/lib/libc/posix1e/acl_perm.c
+++ b/lib/libc/posix1e/acl_perm.c
@@ -51,11 +51,11 @@ acl_add_perm(acl_permset_t permset_d, acl_perm_t perm)
}
/*
* acl_clear_perm() clears all permisions from the permission
* set permset_d
*/
int
-acl_clear_perm(acl_permset_t permset_d)
+acl_clear_perms(acl_permset_t permset_d)
{
if (!permset_d) {
OpenPOWER on IntegriCloud
@@ -51,11 +51,11 @@ acl_add_perm(acl_permset_t permset_d, acl_perm_t perm)
}
/*
- * acl_clear_perm() clears all permisions from the permission
+ * acl_clear_perms() clears all permisions from the permission
* set permset_d
*/